# pyDySP

Dynamic Signal Processing

[![Read the Docs](https://img.shields.io/readthedocs/pydysp)](https://pydysp.readthedocs.io/en/latest/)
![GitHub License](https://img.shields.io/github/license/dkaramitros/python-dysp)

## Information

Python classes are provided to process laboratory data from the Shaking Table experimental facilities at the University of Bristol.

## Instructions

The package `pyDySP` includes two classes:

- The `Test` class provides methods to add, manage, and plot data from multiple channels. Transfer functions can also be produced and analyzed.

- The `Channel` class provides methods for signal processing, including baseline correction, filtering, and trimming. Plotting methods are also provided.

Example Jupyter notebooks are also provided.